@@ -7,12 +7,15 @@
 #ifndef SONNET_CONFIGWIDGET_H
 #define SONNET_CONFIGWIDGET_H
 
-#include <QWidget>
-class ConfigWidgetPrivate;
 #include "sonnetui_export.h"
+#include <QWidget>
+
+#include <memory>
 
 namespace Sonnet
 {
+class ConfigWidgetPrivate;
+
 /// The sonnet ConfigWidget
 class SONNETUI_EXPORT ConfigWidget : public QWidget
 {
@@ -49,8 +52,8 @@ protected Q_SLOTS:
     void slotIgnoreWordRemoved();
     void slotIgnoreWordAdded();
 private Q_SLOTS:
-    void slotUpdateButton(const QString &text);
-    void slotSelectionChanged();
+    SONNETUI_NO_EXPORT void slotUpdateButton(const QString &text);
+    SONNETUI_NO_EXPORT void slotSelectionChanged();
 
 Q_SIGNALS:
     /**
@@ -60,10 +63,10 @@ Q_SIGNALS:
     void configChanged();
 
 private:
-    void setFromGui();
+    SONNETUI_NO_EXPORT void setFromGui();
 
 private:
-    ConfigWidgetPrivate *const d;
+    std::unique_ptr<ConfigWidgetPrivate> const d;
 };
 }
 
